@@ -1,7 +1,7 @@
 use std::iter::repeat_with;
 
 use futuresdr::anyhow::Result;
-use futuresdr::blocks::ThrottleBuilder;
+use futuresdr::blocks::Throttle;
 use futuresdr::blocks::VectorSourceBuilder;
 use futuresdr::blocks::WebsocketSinkBuilder;
 use futuresdr::runtime::Flowgraph;
@@ -14,7 +14,7 @@ fn main() -> Result<()> {
     let orig: Vec<u8> = repeat_with(rand::random::<u8>).take(n_items).collect();
 
     let src = VectorSourceBuilder::<u8>::new(orig).build();
-    let throttle = ThrottleBuilder::new(1, 100.0).build();
+    let throttle = Throttle::<u8>::new(100.0);
     let snk = WebsocketSinkBuilder::<u8>::new(9001).build();
 
     let src = fg.add_block(src);
