@@ -8,33 +8,33 @@ mod combine;
 pub use combine::Combine;
 
 mod copy;
-pub use copy::{Copy, CopyBuilder};
+pub use copy::Copy;
 mod copy_rand;
 pub use copy_rand::{CopyRand, CopyRandBuilder};
 mod filter;
 pub use filter::Filter;
+
+#[cfg_attr(RUSTC_IS_STABLE, path = "fir_stable.rs")]
 mod fir;
 pub use fir::Fir;
 
-#[cfg(not(target_arch = "wasm32"))]
 mod fft;
-#[cfg(not(target_arch = "wasm32"))]
 pub use fft::{Fft, FftBuilder};
 
 #[cfg(not(target_arch = "wasm32"))]
 mod file_sink;
 #[cfg(not(target_arch = "wasm32"))]
-pub use file_sink::{FileSink, FileSinkBuilder};
+pub use file_sink::FileSink;
 
 #[cfg(not(target_arch = "wasm32"))]
 mod file_source;
 #[cfg(not(target_arch = "wasm32"))]
-pub use file_source::{FileSource, FileSourceBuilder};
+pub use file_source::FileSource;
 
 mod finite_source;
 pub use finite_source::FiniteSource;
 mod head;
-pub use head::{Head, HeadBuilder};
+pub use head::Head;
 
 #[cfg(feature = "lttng")]
 pub mod lttng;
@@ -52,9 +52,9 @@ mod message_source;
 pub use message_source::{MessageSource, MessageSourceBuilder};
 
 mod null_sink;
-pub use null_sink::{NullSink, NullSinkBuilder};
+pub use null_sink::NullSink;
 mod null_source;
-pub use null_source::{NullSource, NullSourceBuilder};
+pub use null_source::NullSource;
 
 #[cfg(feature = "soapy")]
 mod soapy_src;
@@ -79,7 +79,7 @@ pub use tcp_source::{TcpSource, TcpSourceBuilder};
 #[cfg(not(target_arch = "wasm32"))]
 mod throttle;
 #[cfg(not(target_arch = "wasm32"))]
-pub use throttle::{Throttle, ThrottleBuilder};
+pub use throttle::Throttle;
 
 mod vector_sink;
 pub use vector_sink::{VectorSink, VectorSinkBuilder};
@@ -91,11 +91,25 @@ mod vulkan;
 #[cfg(feature = "vulkan")]
 pub use vulkan::{Vulkan, VulkanBuilder};
 
+#[cfg(target_arch = "wasm32")]
+mod wasm_sdr;
+#[cfg(target_arch = "wasm32")]
+pub use wasm_sdr::WasmSdr;
+#[cfg(target_arch = "wasm32")]
+mod wasm_freq;
+#[cfg(target_arch = "wasm32")]
+pub use wasm_freq::WasmFreq;
+
 #[cfg(not(target_arch = "wasm32"))]
 mod websocket_sink;
 #[cfg(not(target_arch = "wasm32"))]
 pub use websocket_sink::{WebsocketSink, WebsocketSinkBuilder, WebsocketSinkMode};
 
+#[cfg(feature = "wgpu")]
+mod wgpu;
+#[cfg(feature = "wgpu")]
+pub use self::wgpu::Wgpu;
+
 #[cfg(feature = "zeromq")]
 pub mod zeromq;
 
@@ -103,3 +117,8 @@ pub mod zeromq;
 mod zynq;
 #[cfg(feature = "zynq")]
 pub use zynq::{Zynq, ZynqBuilder};
+
+#[cfg(feature = "zynq")]
+mod zynq_sync;
+#[cfg(feature = "zynq")]
+pub use zynq_sync::{ZynqSync, ZynqSyncBuilder};
