@@ -15,34 +15,34 @@ use crate::runtime::StreamIo;
 use crate::runtime::StreamIoBuilder;
 use crate::runtime::WorkIo;
 
-pub struct Throttle {
-    item_size: usize,
+pub struct Throttle<T: Send + 'static> {
     rate: f64,
     t_init: Instant,
     n_items: usize,
+    _type: std::marker::PhantomData<T>,
 }
 
-impl Throttle {
-    pub fn new(item_size: usize, rate: f64) -> Block {
+impl<T: Send + 'static> Throttle<T> {
+    pub fn new(rate: f64) -> Block {
         Block::new_async(
             BlockMetaBuilder::new("Throttle").build(),
             StreamIoBuilder::new()
-                .add_input("in", item_size)
-                .add_output("out", item_size)
+                .add_input("in", std::mem::size_of::<T>())
+                .add_output("out", std::mem::size_of::<T>())
                 .build(),
-            MessageIoBuilder::<Throttle>::new().build(),
-            Throttle {
-                item_size,
+            MessageIoBuilder::<Self>::new().build(),
+            Throttle::<T> {
                 rate,
                 t_init: Instant::now(),
                 n_items: 0,
+                _type: std::marker::PhantomData,
             },
         )
     }
 }
 
 #[async_trait]
-impl AsyncKernel for Throttle {
+impl<T: Send + 'static> AsyncKernel for Throttle<T> {
     async fn work(
         &mut self,
         io: &mut WorkIo,
@@ -52,9 +52,7 @@ impl AsyncKernel for Throttle {
     ) -> Result<()> {
         let i = sio.input(0).slice::<u8>();
         let o = sio.output(0).slice::<u8>();
-
-        debug_assert_eq!(i.len() % self.item_size, 0);
-        debug_assert_eq!(o.len() % self.item_size, 0);
+        let item_size = std::mem::size_of::<T>();
 
         let mut m = cmp::min(i.len(), o.len());
 
@@ -62,19 +60,19 @@ impl AsyncKernel for Throttle {
         let target_items = (now - self.t_init).as_secs_f64() * self.rate;
         let target_items = target_items.floor() as usize;
 
-        m = cmp::min(m, (target_items - self.n_items) * self.item_size) as usize;
+        m = cmp::min(m, (target_items - self.n_items) * item_size) as usize;
         if m != 0 {
             unsafe {
                 ptr::copy_nonoverlapping(i.as_ptr(), o.as_mut_ptr(), m);
             }
 
-            let m = m / self.item_size;
+            let m = m / item_size;
             self.n_items += m;
             sio.input(0).consume(m);
             sio.output(0).produce(m);
         }
 
-        if sio.input(0).finished() && i.len() == m * self.item_size {
+        if sio.input(0).finished() && i.len() == m * item_size {
             io.finished = true;
         }
 
@@ -96,18 +94,3 @@ impl AsyncKernel for Throttle {
         Ok(())
     }
 }
-
-pub struct ThrottleBuilder {
-    item_size: usize,
-    rate: f64,
-}
-
-impl ThrottleBuilder {
-    pub fn new(item_size: usize, rate: f64) -> ThrottleBuilder {
-        ThrottleBuilder { item_size, rate }
-    }
-
-    pub fn build(self) -> Block {
-        Throttle::new(self.item_size, self.rate)
-    }
-}
