@@ -1,8 +1,8 @@
-use anyhow::Result;
 use std::cmp;
 use std::mem;
 use std::ptr;
 
+use crate::anyhow::Result;
 use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
@@ -64,7 +64,7 @@ impl<T: Send + 'static> AsyncKernel for VectorSource<T> {
     }
 }
 
-pub struct VectorSourceBuilder<T: Send> {
+pub struct VectorSourceBuilder<T> {
     items: Vec<T>,
 }
 
